@@ -452,6 +452,7 @@ RZ_API RZ_OWN RzILOpBool *rz_il_op_new_bool_inv(RZ_NONNULL RzILOpBool *x);
 RZ_API RZ_OWN RzILOpBitVector *rz_il_op_new_bitv(RZ_NONNULL RzBitVector *value);
 RZ_API RZ_OWN RzILOpBitVector *rz_il_op_new_bitv_from_ut64(ut32 length, ut64 number);
 RZ_API RZ_OWN RzILOpBitVector *rz_il_op_new_bitv_from_st64(ut32 length, st64 number);
+RZ_API RZ_OWN RzILOpBool *rz_il_op_new_bitv_max(ut32 length);
 RZ_API RZ_OWN RzILOpBool *rz_il_op_new_msb(RZ_NONNULL RzILOpPure *val);
 RZ_API RZ_OWN RzILOpBool *rz_il_op_new_lsb(RZ_NONNULL RzILOpPure *val);
 RZ_API RZ_OWN RzILOpBool *rz_il_op_new_is_zero(RZ_NONNULL RzILOpPure *bv);
@@ -495,6 +496,7 @@ typedef enum {
 	RZ_IL_OP_STORE,
 	RZ_IL_OP_STOREW,
 
+	RZ_IL_OP_EMPTY,
 	RZ_IL_OP_NOP,
 	RZ_IL_OP_SET,
 	RZ_IL_OP_JMP,
@@ -525,6 +527,7 @@ struct rz_il_op_effect_t {
 
 RZ_API void rz_il_op_effect_free(RZ_NULLABLE RzILOpEffect *op);
 
+RZ_API RZ_OWN RzILOpEffect *rz_il_op_new_empty();
 RZ_API RZ_OWN RzILOpEffect *rz_il_op_new_nop();
 RZ_API RZ_OWN RzILOpEffect *rz_il_op_new_set(RZ_NONNULL const char *v, bool is_local, RZ_NONNULL RzILOpPure *x);
 RZ_API RZ_OWN RzILOpEffect *rz_il_op_new_jmp(RZ_NONNULL RzILOpBitVector *dst);
